@@ -37,11 +37,43 @@ package PPIx::Regexp::Structure::Code;
 use strict;
 use warnings;
 
-use Params::Util 0.25 qw{ _INSTANCE };
-
 use base qw{ PPIx::Regexp::Structure };
 
-our $VERSION = '0.007';
+use Carp qw{ cluck };
+use PPIx::Regexp::Constant qw{ STRUCTURE_UNKNOWN TOKEN_UNKNOWN };
+
+our $VERSION = '0.020';
+
+# The only child of this structure should be a single
+# PPIx::Regexp::Token::Code. Anything else gets turned into the
+# appropriate ::Unknown object.
+sub __PPIX_LEXER__finalize {
+    my ( $self ) = @_;
+
+    my $count;
+    my $errors = 0;
+
+    foreach my $kid ( $self->children() ) {
+
+	$kid->isa( 'PPIx::Regexp::Token::Code' )
+	    and not $count++
+	    and next;
+
+	$errors++;
+
+	if ( $kid->isa( 'PPIx::Regexp::Token' ) ) {
+	    bless $kid, TOKEN_UNKNOWN;
+	} elsif ( $kid->isa( 'PPIx::Regexp::Structure' ) ) {
+	    bless $kid, STRUCTURE_UNKNOWN;
+	} else {
+	    cluck( 'Programming error - unexpected element of class ',
+		ref $kid, ' found in a PPIx::Regexp::Structure::Code. ',
+		'Please contact the author' );
+	}
+
+    }
+    return $errors;
+}
 
 1;
 
@@ -58,7 +90,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, Thomas R. Wyant, III
+Copyright (C) 2009-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
