@@ -51,7 +51,7 @@ use warnings;
 
 use base qw{PPIx::Regexp::Element};
 
-our $VERSION = '0.007';
+our $VERSION = '0.020';
 
 sub _new {
     my ( $class, $content ) = @_;
@@ -70,30 +70,6 @@ sub content {
     return $self->{content};
 }
 
-=head2 can_be_quantified
-
- $token->can_be_quantified()
-     and print "This token can be quantified.\n";
-
-This method returns true if the token can be quantified.
-
-=cut
-
-sub can_be_quantified { return 1 };
-
-=head2 is_quantifier
-
- $token->is_quantifier()
-     and print "This token is a quantifier.\n";
-
-This method returns true if the token is a quantifier. You can not tell
-this from the token's class, because a right curly bracket may represent
-a quantifier for the purposes of figuring out whether a greediness token
-is possible.
-
-=cut
-
-sub is_quantifier { return };
 
 # Called after the token is manufactured. The calling sequence is
 # $token->__PPIX_TOKEN__post_make( $tokenizer );
@@ -121,7 +97,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, Thomas R. Wyant, III
+Copyright (C) 2009-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
