@@ -6,12 +6,16 @@ use warnings;
 use base qw{ PPIx::Regexp::Support };
 
 use Carp qw{ confess };
-use Params::Util 0.25 qw{ _INSTANCE };
-use PPIx::Regexp::Constant qw{ $TOKEN_LITERAL $TOKEN_UNKNOWN };
+use PPIx::Regexp::Constant qw{
+    MINIMUM_PERL
+    TOKEN_LITERAL
+    TOKEN_UNKNOWN
+};
 use PPIx::Regexp::Token::Assertion		();
 use PPIx::Regexp::Token::Backreference		();
 use PPIx::Regexp::Token::Backtrack		();
 use PPIx::Regexp::Token::CharClass::POSIX	();
+use PPIx::Regexp::Token::CharClass::POSIX::Unknown	();
 use PPIx::Regexp::Token::CharClass::Simple	();
 use PPIx::Regexp::Token::Code			();
 use PPIx::Regexp::Token::Comment		();
@@ -35,18 +39,19 @@ use PPIx::Regexp::Token::Recursion		();
 use PPIx::Regexp::Token::Structure		();
 use PPIx::Regexp::Token::Unknown		();
 use PPIx::Regexp::Token::Whitespace		();
+use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.007';
+our $VERSION = '0.020';
 
 {
-    # Names of classes containing tokenization machinery. There are no
+    # Names of classes containing tokenization machinery. There are few
     # known ordering requirements, since each class recognizes its own,
     # and I have tried to prevent overlap. Absent such constraints, the
     # order is in percieved frequency of acceptance, to keep the search
     # as short as possible. If I were conscientious I would gather
     # statistics on this.
-    my @classes = (
+    my @classes = (	# TODO make readonly when acceptable way appears
 	'PPIx::Regexp::Token::Literal',
 	'PPIx::Regexp::Token::Interpolation',
 	'PPIx::Regexp::Token::Control',			# Note 1
@@ -160,13 +165,13 @@ our $VERSION = '0.007';
 	    mode => 'init',	# Initialize
 	    modifiers => [{}],	# Modifier hash.
 	    pending => [],	# Tokens made but not returned.
-	    prior => $TOKEN_UNKNOWN,	# Prior significant token.
+	    prior => TOKEN_UNKNOWN,	# Prior significant token.
 	    source => $re,	# The object we were initialized with.
 	    trace => __PACKAGE__->_defined_or(
 		$args{trace}, $ENV{PPIX_REGEXP_TOKENIZER_TRACE}, 0 ),
 	};
 
-	if ( _INSTANCE( $re, 'PPI::Element' ) ) {
+	if ( __instance( $re, 'PPI::Element' ) ) {
 	    $self->{content} = $re->content();
 	} elsif ( ref $re ) {
 	    $errstr = ref( $re ) . ' not supported';
@@ -241,9 +246,9 @@ sub failures {
 }
 
 sub find_matching_delimiter {
-    my ( $self, $start ) = @_;
+    my ( $self ) = @_;
     $self->{cursor_curr} ||= 0;
-    defined $start or $start = substr
+    my $start = substr
 	$self->{content},
 	$self->{cursor_curr},
 	1;
@@ -351,10 +356,10 @@ sub make_token {
     "cursor_limit = $self->{cursor_limit}\n";
     my $token = $class->_new( $content ) or return;
     $token->significant() and $self->{expect} = undef;
-    $class eq $TOKEN_UNKNOWN and $self->{failures}++;
-
     $token->__PPIX_TOKEN__post_make( $self, $arg );
 
+    $token->isa( TOKEN_UNKNOWN ) and $self->{failures}++;
+
     $self->{cursor_curr} += $length;
     $self->{find} = undef;
     $self->{match} = undef;
@@ -395,24 +400,13 @@ sub modifier_duplicate {
 sub modifier_modify {
     my ( $self, %args ) = @_;
 
-    # Get the current modifiers
-    my %mods = %{ $self->{modifiers}[-1] };
+    # Modifier code is centralized in PPIx::Regexp::Token::Modifier
+    $self->{modifiers}[-1] =
+	PPIx::Regexp::Token::Modifier::__PPIX_TOKENIZER__modifier_modify(
+	$self->{modifiers}[-1], \%args );
 
-    # Update the values
-    while ( my ( $key, $val ) = each %args ) {
-	if ( $val ) {
-	    $mods{$key} = $val;
-	} else {
-	    delete $mods{$key};
-	}
-    }
-
-    # Replace the modifiers (rather than simply changing them). We do it
-    # this way because of the possibility we may want to carry the
-    # current modifier value with the token so that the old object (now
-    # abandoned) keeps its value.
-    $self->{modifiers}[-1] = \%mods;
     return;
+
 }
 
 sub modifier_pop {
@@ -439,14 +433,6 @@ sub next_token {
 	    $self->{cursor_limit}++;
 	}
 
-	my $handler = '__PPIX_TOKENIZER__' . $self->{mode};
-
-	my $character = substr(
-	    $self->{content},
-	    $self->{cursor_curr},
-	    1
-	);
-
 	if ( my @tokens = $self->get_token() ) {
 	    push @{ $self->{pending} }, @tokens;
 	    redo;
@@ -519,10 +505,11 @@ sub __PPIX_TOKENIZER__init {
     my ( $class, $tokenizer, $character ) = @_;
 
     $tokenizer->{mode} = 'kaput';
-    $tokenizer->{content} =~ m/ ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
+    $tokenizer->{content} =~ m/ \A ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
 	or return $tokenizer->make_token(
-	    length( $tokenizer->{content} ), $TOKEN_UNKNOWN );
-    my ( $type, $white, $delim ) = ( $1, $2, $3 );
+	    length( $tokenizer->{content} ), TOKEN_UNKNOWN );
+#   my ( $type, $white, $delim ) = ( $1, $2, $3 );
+    my ( $type, $white ) = ( $1, $2 );
     defined $type or $type = '';
     $tokenizer->{type} = $type;
 
@@ -533,12 +520,15 @@ sub __PPIX_TOKENIZER__init {
 	and push @tokens, $tokenizer->make_token( length $white,
 	'PPIx::Regexp::Token::Whitespace' );
 
+    $tokenizer->{modifiers} = [ {} ];
     if ( $tokenizer->{content} =~ m/ ( [[:lower:]]* ) \s* \z /smx ) {
-	$tokenizer->{cursor_limit} -= length( $1 );
-	$tokenizer->{modifiers} =
-	    [ { map { $_ => 1 } split qr{}smx, $1 } ];
-    } else {
-	$tokenizer->{modifiers} = [ {} ];
+	local $_ = $1;
+	$tokenizer->{cursor_limit} -= length $_;
+	# Can't use a split() here, because we need to distinguish
+	# between s/.../.../e and s/.../.../ee.
+	while ( m/ ( ( . ) \2* ) /smxg ) {
+	    $tokenizer->{modifiers}[0]{$1} = 1;
+	}
     }
     $tokenizer->{cursor_modifiers} = $tokenizer->{cursor_limit};
 
@@ -601,11 +591,11 @@ sub __PPIX_TOKEN_FALLBACK__regexp {
     if ( $character eq '\\'
 	&& $tokenizer->{cursor_limit} - $tokenizer->{cursor_curr} > 1
     ) {
-	return $tokenizer->make_token( 2, $TOKEN_LITERAL );
+	return $tokenizer->make_token( 2, TOKEN_LITERAL );
     }
 
     # Any normal character is unknown.
-    return $tokenizer->make_token( 1, $TOKEN_UNKNOWN );
+    return $tokenizer->make_token( 1, TOKEN_UNKNOWN );
 }
 
 sub __PPIX_TOKEN_FALLBACK__repl {
@@ -616,13 +606,13 @@ sub __PPIX_TOKEN_FALLBACK__repl {
 	&& defined ( my $next = $tokenizer->peek( 1 ) ) ) {
 
 	if ( $tokenizer->interpolates() || $next eq q<'> || $next eq '\\' ) {
-	    return $tokenizer->make_token( 2, $TOKEN_LITERAL );
+	    return $tokenizer->make_token( 2, TOKEN_LITERAL );
 	}
-	return $tokenizer->make_token( 1, $TOKEN_LITERAL );
+	return $tokenizer->make_token( 1, TOKEN_LITERAL );
     }
 
     # So is any normal character.
-    return $tokenizer->make_token( 1, $TOKEN_LITERAL );
+    return $tokenizer->make_token( 1, TOKEN_LITERAL );
 }
 
 sub __PPIX_TOKENIZER__finish {
@@ -676,7 +666,9 @@ sub __PPIX_TOKENIZER__finish {
 	    # trailing delimiter and modifiers, and return it all.
 	    push @tokens, $tokenizer->make_token(
 		$tokenizer->{cursor_limit} - $tokenizer->{cursor_curr},
-		'PPIx::Regexp::Token::Code' );
+		'PPIx::Regexp::Token::Code',
+		{ perl_version_introduced => MINIMUM_PERL },
+	    );
 	    $tokenizer->{cursor_limit} = length $tokenizer->{content};
 	    push @tokens, $tokenizer->make_token( 1,
 		'PPIx::Regexp::Token::Delimiter' );
@@ -919,6 +911,16 @@ character at the current position in the content string. If the
 delimiter is an opening bracket of some sort, bracket nesting will be
 taken into account.
 
+When searching for the matching delimiter, the back slash character is
+considered to escape the following character, so back-slashed delimiters
+will be ignored. No other quoting mechanisms are recognized, though, so
+delimiters inside quotes still count. This is actually the way Perl
+works, as
+
+ $ perl -e 'qr<(?{ print "}" })>'
+
+demonstrates.
+
 This method returns the offset from the current position in the content
 string to the matching delimiter (which will always be positive), or
 undef if no match can be found.
@@ -1061,7 +1063,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, Thomas R. Wyant, III
+Copyright (C) 2009-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
